Skip to contents

Returns the range of years for which enrollment data is available from the Louisiana Department of Education (LDOE).

Usage

get_available_years()

Value

A list with:

min_year

First available year (2019)

max_year

Last available year (2026)

description

Description of data availability

Examples

years <- get_available_years()
print(years$min_year)
#> [1] 2019
print(years$max_year)
#> [1] 2026